@@ -3,8 +3,8 @@ Protocol versions 1.0, 1.1 and 1.2 are supported.
 
 See the GITHUB project page for more information.
 
-Author: Jason R Briggs
-License: http://www.apache.org/licenses/LICENSE-2.0
+Author: Jason R Briggs |br|
+License: http://www.apache.org/licenses/LICENSE-2.0 |br|
 Project Page: https://github.com/jasonrbriggs/stomp.py
 
 """
@@ -14,7 +14,7 @@ import stomp.connect as connect
 import stomp.listener as listener
 import stomp.logging as logging
 
-__version__ = (6, 1, 0)
+__version__ = (8, 0, 0)
 
 ##
 # Alias for STOMP 1.0 connections.
