@@ -1,7 +1,6 @@
 """Various listeners for using with stomp.py connections.
 """
 
-import os
 import sys
 import threading
 import time
@@ -51,6 +50,7 @@ class ConnectionListener(object):
     This class should be used as a base class for objects registered
     using Connection.set_listener().
     """
+
     def on_connecting(self, host_and_port):
         """
         Called by the STOMP connection once a TCP/IP connection to the
@@ -70,9 +70,15 @@ class ConnectionListener(object):
         received (after a connection has been established or
         re-established).
 
-        :param dict headers: a dictionary containing all headers sent by the server as key/value pairs.
-        :param body: the frame's payload. This is usually empty for CONNECTED frames.
+        :param Frame frame: the stomp frame
         """
+        pass
+
+    def on_disconnecting(self):
+        """
+        Called before a DISCONNECT frame is sent.
+        """
+        pass
 
     def on_disconnected(self):
         """
@@ -94,8 +100,7 @@ class ConnectionListener(object):
         Called by the STOMP connection before a message is returned to the client app. Returns a tuple
         containing the headers and body (so that implementing listeners can pre-process the content).
 
-        :param dict headers: the message headers
-        :param body: the message body
+        :param Frame frame: the stomp frame
         """
         pass
 
@@ -103,8 +108,7 @@ class ConnectionListener(object):
         """
         Called by the STOMP connection when a MESSAGE frame is received.
 
-        :param dict headers: a dictionary containing all headers sent by the server as key/value pairs.
-        :param body: the frame's payload - the message body.
+        :param Frame frame: the stomp frame
         """
         pass
 
@@ -114,8 +118,7 @@ class ConnectionListener(object):
         received, sent by the server if requested by the client using
         the 'receipt' header.
 
-        :param dict headers: a dictionary containing all headers sent by the server as key/value pairs.
-        :param body: the frame's payload. This is usually empty for RECEIPT frames.
+        :param Frame frame: the stomp frame
         """
         pass
 
@@ -123,8 +126,7 @@ class ConnectionListener(object):
         """
         Called by the STOMP connection when an ERROR frame is received.
 
-        :param dict headers: a dictionary containing all headers sent by the server as key/value pairs.
-        :param body: the frame's payload - usually a detailed error description.
+        :param Frame frame: the stomp frame
         """
         pass
 
@@ -132,7 +134,7 @@ class ConnectionListener(object):
         """
         Called by the STOMP connection when it is in the process of sending a message
 
-        :param Frame frame: the frame to be sent
+        :param Frame frame: the stomp frame
         """
         pass
 
@@ -162,6 +164,7 @@ class HeartbeatListener(ConnectionListener):
         self.next_outbound_heartbeat = None
         self.heart_beat_receive_scale = heart_beat_receive_scale
         self.heartbeat_terminate_event = threading.Event()
+        self.disconnecting = False
 
     def on_connected(self, frame):
         """
@@ -169,12 +172,12 @@ class HeartbeatListener(ConnectionListener):
         heartbeat numbers (based on what the server sent and what was specified by the client) - if the heartbeats
         are not 0, we start up the heartbeat loop accordingly.
 
-        :param dict headers: headers in the connection message
-        :param body: the message body
+        :param Frame frame: the stomp frame
         """
+        self.disconnecting = False
         if "heart-beat" in frame.headers:
             self.heartbeats = utils.calculate_heartbeats(
-                frame.headers["heart-beat"].replace(' ', '').split(','), self.heartbeats)
+                frame.headers["heart-beat"].replace(" ", "").split(","), self.heartbeats)
             logging.debug("Heartbeats calculated %s", str(self.heartbeats))
             if self.heartbeats != (0, 0):
                 self.send_sleep = self.heartbeats[0] / 1000
@@ -199,12 +202,14 @@ class HeartbeatListener(ConnectionListener):
         self.running = False
         self.heartbeat_terminate_event.set()
 
+    def on_disconnecting(self):
+        self.disconnecting = True
+
     def on_message(self, frame):
         """
         Reset the last received time whenever a message is received.
 
-        :param dict headers: headers in the message
-        :param body: the message content
+        :param Frame frame: the stomp frame
         """
         # reset the heartbeat for any received message
         self.__update_heartbeat()
@@ -234,9 +239,8 @@ class HeartbeatListener(ConnectionListener):
 
         :param Frame frame: the Frame object
         """
-        if frame.cmd == CMD_CONNECT or frame.cmd == CMD_STOMP:
-            if self.heartbeats != (0, 0):
-                frame.headers[HDR_HEARTBEAT] = "%s,%s" % self.heartbeats
+        if frame.cmd in [CMD_CONNECT, CMD_STOMP] and self.heartbeats != (0, 0):
+            frame.headers[HDR_HEARTBEAT] = "%s,%s" % self.heartbeats
         if self.next_outbound_heartbeat is not None:
             self.next_outbound_heartbeat = monotonic() + self.send_sleep
 
@@ -270,7 +274,7 @@ class HeartbeatListener(ConnectionListener):
                 t = self.received_heartbeat + self.receive_sleep - now
                 if t > 0:
                     next_events.append(t)
-            sleep_time = min(next_events)
+            sleep_time = min(next_events) if next_events else 0
             if sleep_time > 0:
                 terminate = self.heartbeat_terminate_event.wait(sleep_time)
                 if terminate:
@@ -278,7 +282,7 @@ class HeartbeatListener(ConnectionListener):
 
             now = monotonic()
 
-            if not self.transport.is_connected():
+            if not self.transport.is_connected() or self.disconnecting:
                 time.sleep(self.send_sleep)
                 continue
 
@@ -298,7 +302,7 @@ class HeartbeatListener(ConnectionListener):
                 if diff_receive > self.receive_sleep:
                     # heartbeat timeout
                     logging.warning("Heartbeat timeout: diff_receive=%s, time=%s, lastrec=%s",
-                                diff_receive, now, self.received_heartbeat)
+                                    diff_receive, now, self.received_heartbeat)
                     self.transport.set_connected(False)
                     self.transport.disconnect_socket()
                     self.transport.stop()
@@ -329,8 +333,7 @@ class WaitingListener(ConnectionListener):
         """
         If the receipt id can be found in the headers, then notify the waiting thread.
 
-        :param dict headers: headers in the message
-        :param body: the message content
+        :param Frame frame: the stomp frame
         """
         if "receipt-id" in frame.headers and frame.headers["receipt-id"] == self.receipt:
             with self.receipt_condition:
@@ -359,6 +362,7 @@ class WaitingListener(ConnectionListener):
             while not self.disconnected:
                 self.disconnect_condition.wait()
 
+
 class StatsListener(ConnectionListener):
     """
     A connection listener for recording statistics on messages sent and received.
@@ -390,8 +394,7 @@ class StatsListener(ConnectionListener):
         """
         Increment the error count. See :py:meth:`ConnectionListener.on_error`
 
-        :param dict headers: headers in the message
-        :param body: the message content
+        :param Frame frame: the stomp frame
         """
         if logging.isEnabledFor(logging.DEBUG):
             logging.debug("received an error %s [%s]", frame.body, frame.headers)
@@ -412,8 +415,7 @@ class StatsListener(ConnectionListener):
         """
         Increment the message received count. See :py:meth:`ConnectionListener.on_message`
 
-        :param dict headers: headers in the message
-        :param body: the message content
+        :param Frame frame: the stomp frame
         """
         self.messages += 1
 
@@ -448,7 +450,8 @@ Disconnects: %s
 Messages sent: %s
 Messages received: %s
 Heartbeats received: %s
-Errors: %s''' % (self.connections, self.disconnects, self.messages_sent, self.messages, self.heartbeat_count, self.errors)
+Errors: %s''' % (self.connections, self.disconnects, self.messages_sent, self.messages,
+                 self.heartbeat_count, self.errors)
 
 
 class PrintingListener(ConnectionListener):
@@ -469,8 +472,7 @@ class PrintingListener(ConnectionListener):
 
     def on_connected(self, frame):
         """
-        :param dict headers:
-        :param body:
+        :param Frame frame: the stomp frame
         """
         self.__print("on_connected %s %s", frame.headers, frame.body)
 
@@ -482,35 +484,31 @@ class PrintingListener(ConnectionListener):
 
     def on_before_message(self, frame):
         """
-        :param dict headers:
-        :param body:
+        :param Frame frame: the stomp frame
         """
         self.__print("on_before_message %s %s", frame.headers, frame.body)
 
     def on_message(self, frame):
         """
-        :param dict headers:
-        :param body:
+        :param Frame frame: the stomp frame
         """
         self.__print("on_message %s %s", frame.headers, frame.body)
 
     def on_receipt(self, frame):
         """
-        :param dict headers:
-        :param body:
+        :param Frame frame: the stomp frame
         """
         self.__print("on_receipt %s %s", frame.headers, frame.body)
 
     def on_error(self, frame):
         """
-        :param dict headers:
-        :param body:
+        :param Frame frame: the stomp frame
         """
         self.__print("on_error %s %s", frame.headers, frame.body)
 
     def on_send(self, frame):
         """
-        :param Frame frame:
+        :param Frame frame: the stomp frame
         """
         self.__print("on_send %s %s %s", frame.cmd, utils.clean_headers(frame.headers), frame.body)
 
@@ -578,8 +576,7 @@ class TestListener(StatsListener, WaitingListener, PrintingListener):
 
     def on_message(self, frame):
         """
-        :param dict headers:
-        :param message:
+        :param Frame frame: the stomp frame
         """
         StatsListener.on_message(self, frame)
         PrintingListener.on_message(self, frame)
