@@ -2,7 +2,6 @@
 """
 
 import copy
-import logging
 import os
 import re
 import socket
@@ -17,7 +16,7 @@ from stomp.constants import *
 # preferred targets.
 LOCALHOST_NAMES = ["localhost", "127.0.0.1"]
 
-NULL = b'\x00'
+NULL = b"\x00"
 
 if not os.environ.get("STOMP_SKIP_HOSTNAME_SCAN"):
     try:
@@ -41,6 +40,7 @@ def decode(byte_data, encoding="utf-8"):
     Decode the byte data to a string if not None.
 
     :param bytes byte_data: the data to decode
+    :param string encoding: character encoding
 
     :rtype: str
     """
@@ -54,6 +54,7 @@ def encode(char_data, encoding="utf-8"):
     Encode the parameter as a byte string.
 
     :param char_data: the data to encode
+    :param string encoding: character encoding
 
     :rtype: bytes
     """
@@ -73,7 +74,7 @@ def pack(pieces=()):
 
     :rtype: bytes
     """
-    return b''.join(pieces)
+    return b"".join(pieces)
 
 
 def join(chars=()):
@@ -84,11 +85,12 @@ def join(chars=()):
 
     :rtype: str
     """
-    return b''.join(chars).decode()
+    return b"".join(chars).decode()
 
 
 def is_eol_default(c):
-    return c == b'\x0a'
+    return c == b"\x0a"
+
 
 ##
 # Used to parse STOMP header lines in the format "key:value",
@@ -144,10 +146,10 @@ def is_localhost(host_and_port):
 
 
 _HEADER_ESCAPES = {
-    '\r': '\\r',
-    '\n': '\\n',
-    ':': '\\c',
-    '\\': '\\\\',
+    "\r": "\\r",
+    "\n": "\\n",
+    ":": "\\c",
+    "\\": "\\\\",
 }
 _HEADER_UNESCAPES = dict((value, key) for (key, value) in _HEADER_ESCAPES.items())
 
@@ -175,10 +177,10 @@ def parse_headers(lines, offset=0):
         header_match = HEADER_LINE_RE.match(header_line)
         if header_match:
             key = header_match.group("key")
-            key = re.sub(r'\\.', _unescape_header, key)
+            key = re.sub(r"\\.", _unescape_header, key)
             if key not in headers:
                 value = header_match.group("value")
-                value = re.sub(r'\\.', _unescape_header, value)
+                value = re.sub(r"\\.", _unescape_header, value)
                 headers[key] = value
     return headers
 
@@ -262,9 +264,9 @@ def calculate_heartbeats(shb, chb):
     (cx, cy) = chb
     x = 0
     y = 0
-    if cx != 0 and sy != '0':
+    if cx != 0 and sy != "0":
         x = max(cx, int(sy))
-    if cy != 0 and sx != '0':
+    if cy != 0 and sx != "0":
         y = max(cy, int(sx))
     return x, y
 
@@ -352,4 +354,4 @@ def get_errno(e):
         return e.args[0]
 
 
-HEARTBEAT_FRAME = Frame("heartbeat")
\ No newline at end of file
+HEARTBEAT_FRAME = Frame("heartbeat")
